@@ -7,8 +7,8 @@ import sqlite3
 import tempfile
 from collections import deque
 from contextlib import contextmanager
-from itertools import (chain, dropwhile, groupby, islice, product,
-                       takewhile, tee)
+from itertools import (chain, dropwhile, groupby, islice, product, takewhile,
+                       tee)
 from pathlib import Path, PurePath
 
 
@@ -29,16 +29,16 @@ class Conn:
         self._dbconn = None
 
     def __getitem__(self, tname):
-        return Dics((self, tname))
+        return Rows((self, tname))
 
     def __setitem__(self, tname, val):
         with _connect(self._dbfile) as c:
             self._dbconn = c
             _delete(c, tname)
-            _insert(c, tname, _dics2iter(val))
+            _insert(c, tname, _rows2iter(val))
 
 
-class Dics:
+class Rows:
     """
     """
 
@@ -73,13 +73,28 @@ class Dics:
     def __getitem__(self, col):
         return [r[col] for r in self.iter()]
 
+    def zip(self, other):
+        pgen = self._genfns[-1]
+
+        def gen():
+            for r1, r2 in zip(pgen(), _rows2iter(other)):
+                r1.update(r2)
+                yield r1
+
+        self._genfns.append(gen)
+        self._insts.append({
+            'cmd': 'zip',
+            'other': other
+        })
+        return self
+
     def chain(self, other):
         pgen = self._genfns[-1]
 
         def gen():
             for r in pgen():
                 yield r
-            for r in _dics2iter(other):
+            for r in _rows2iter(other):
                 yield r
 
         self._genfns.append(gen)
@@ -187,7 +202,7 @@ class Dics:
         pgen = self._genfns[-1]
 
         def gen():
-            yield from _step(fn, pgen(), _dics2iter(other))
+            yield from _step(fn, pgen(), _rows2iter(other))
 
         self._genfns.append(gen)
         self._insts.append({
@@ -201,10 +216,10 @@ class Dics:
         if self._insts[-1]['cmd'] == 'group':
             def _fn2gen(f):
                 def gen(_k, rs):
-                    x = f(Dics(rs))
+                    x = f(Rows(rs))
                     if isinstance(x, dict):
                         yield x
-                    elif isinstance(x, Dics):
+                    elif isinstance(x, Rows):
                         yield from x.iter()
                 return gen
             return self.apply(_fn2gen(fn))
@@ -213,20 +228,20 @@ class Dics:
             def _fn2gen1(f):
 
                 def gen(rs):
-                    x = f(Dics(rs))
+                    x = f(Rows(rs))
                     if isinstance(x, dict):
                         yield x
-                    elif isinstance(x, Dics):
+                    elif isinstance(x, Rows):
                         yield from x.iter()
                 return gen
 
             def _fn2gen2(f):
                 def gen(rs):
                     rs = rs[:step] + [r.copy() for r in rs[step:]]
-                    x = f(Dics(rs))
+                    x = f(Rows(rs))
                     if isinstance(x, dict):
                         yield x
-                    elif isinstance(x, Dics):
+                    elif isinstance(x, Rows):
                         yield from x.iter()
                 return gen
 
@@ -244,7 +259,7 @@ class Dics:
                 x = f(r)
                 if isinstance(x, dict):
                     yield x
-                elif isinstance(x, Dics):
+                elif isinstance(x, Rows):
                     yield from x.iter()
             return gen
         return self.apply(_fn2gen_single(fn))
@@ -286,14 +301,14 @@ class Dics:
             gcols = self._insts[-1]['cols']
 
         def foldfn1(rs):
-            ds = Dics(rs)
+            ds = Rows(rs)
             r = {}
             for k, fn in kwargs.items():
                 r[k] = fn(ds)
             yield r
 
         def foldfn2(keys, rs):
-            ds = Dics(rs)
+            ds = Rows(rs)
             r = dict(zip(gcols, keys))
             for k, fn in kwargs.items():
                 r[k] = fn(ds)
@@ -450,11 +465,11 @@ class Dics:
 
     # experimental
     def tee(self, n):
-        return tuple(Dics(x) for x in tee(self.iter(), n))
+        return tuple(Rows(x) for x in tee(self.iter(), n))
 
     # experimental
     def new(self):
-        return Dics([r.copy() for r in self.iter()])
+        return Rows([r.copy() for r in self.iter()])
 
 
 def _insert_statement(name, d):
@@ -564,8 +579,8 @@ def _step(fn, krs1, krs2):
 
 
 # InstructionSet (It) to iter
-def _dics2iter(obj):
-    return obj.iter() if isinstance(obj, Dics) else iter(obj)
+def _rows2iter(obj):
+    return obj.iter() if isinstance(obj, Rows) else iter(obj)
 
 
 def _build_initgen(conn, tname, cols):
