@@ -36,38 +36,111 @@ class TestCore(unittest.TestCase):
         if Path(self.dbfile1).is_file():
             os.remove(self.dbfile1)
 
+    def test_zip(self):
+        conn = Conn(self.dbfile)
+        conn['t1'] = self.t1
+
+        def tempfn(rs):
+            return rs.zip([
+                {'n': 1},
+                {'n': 2}
+            ])
+
+        conn['t1_1'] = conn['t1'].by('col1').map(tempfn)
+        self.assertEqual(conn['t1_1'].list(),
+                         [{'col1': 'a', 'col2': 4, 'n': 1},
+                          {'col1': 'a', 'col2': 5, 'n': 2},
+                          {'col1': 'b', 'col2': 1, 'n': 1},
+                          {'col1': 'c', 'col2': 3, 'n': 1},
+                          {'col1': 'c', 'col2': 4, 'n': 2},
+                          {'col1': 'd', 'col2': 2, 'n': 1}]
+                         )
+
     def test_tee_n_new(self):
         conn = Conn(self.dbfile)
 
-        def tempfn(ds):
-            ds1, ds2 = ds.tee(2)
-            return ds1.order('col2 desc').chain(ds2.order('col2'))
+        def tempfn(rs):
+            rs1, rs2 = rs.tee(2)
+            return rs1.order('col2 desc').chain(rs2.order('col2'))
 
         conn['t1'] = self.t1
         conn['t1_1'] = conn['t1'].by('col1').map(tempfn)
         self.assertEqual(conn['t1_1']['col2'],
                          [5, 4, 4, 5, 1, 1, 7, 4, 3, 3, 4, 7, 2, 2])
 
-        def tempfn(ds):
-            ds1, ds2 = ds.tee(2)
-            ds1.update(col2=lambda r: r['col2'] + 1)
-            return ds1.order('col2 desc').chain(ds2.order('col2'))
+        def tempfn(rs):
+            rs1, rs2 = rs.tee(2)
+            rs1.update(col2=lambda r: r['col2'] + 1)
+            return rs1.order('col2 desc').chain(rs2.order('col2'))
 
         conn['t1'] = self.t1
         conn['t1_1'] = conn['t1'].by('col1').map(tempfn)
         self.assertEqual(conn['t1_1']['col2'],
                          [6, 5, 5, 6, 2, 2, 8, 5, 4, 4, 5, 8, 3, 3])
 
-        def tempfn(ds):
-            ds1, ds2 = ds.tee(2)
-            ds1.update(col2=lambda r: r['col2'] + 1)
-            return ds1.order('col2 desc').chain(ds2.new().order('col2'))
+        def tempfn(rs):
+            rs1, rs2 = rs.tee(2)
+            rs1.update(col2=lambda r: r['col2'] + 1)
+            return rs1.order('col2 desc').chain(rs2.new().order('col2'))
 
         conn['t1'] = self.t1
         conn['t1_1'] = conn['t1'].by('col1').map(tempfn)
         self.assertEqual(conn['t1_1']['col2'],
                          [6, 5, 4, 5, 2, 1, 8, 5, 4, 3, 4, 7, 3, 2])
 
+    def test_tee_n_new2(self):
+        conn = Conn(self.dbfile)
+
+        def tempfn(rs):
+            rs1, rs2 = rs.tee(2)
+            return rs1.order('col2').zip(rs2.order('col2 desc')
+                                         .rename(col2_1='col2'))
+
+        conn['t1'] = self.t1
+        conn['t1_1'] = conn['t1'].by('col1').map(tempfn)
+        xs = [{'col1': 'a', 'col2': 4, 'col2_1': 5},
+              {'col1': 'a', 'col2': 5, 'col2_1': 4},
+              {'col1': 'b', 'col2': 1, 'col2_1': 1},
+              {'col1': 'c', 'col2': 3, 'col2_1': 7},
+              {'col1': 'c', 'col2': 4, 'col2_1': 4},
+              {'col1': 'c', 'col2': 7, 'col2_1': 3},
+              {'col1': 'd', 'col2': 2, 'col2_1': 2}]
+        self.assertEqual(conn['t1_1'].list(), xs)
+
+        def tempfn1(rs):
+            rs1, rs2 = rs.tee(2)
+            rs1.update(col2=lambda r: r['col2'] + 1)
+            return rs1.order('col2').zip(rs2.order('col2 desc')
+                                         .rename(col2_1='col2'))
+
+        conn['t1_1'] = conn['t1'].by('col1').map(tempfn1)
+
+        xs = [{'col1': 'a', 'col2': 5, 'col2_1': 6},
+              {'col1': 'a', 'col2': 6, 'col2_1': 5},
+              {'col1': 'b', 'col2': 2, 'col2_1': 2},
+              {'col1': 'c', 'col2': 4, 'col2_1': 8},
+              {'col1': 'c', 'col2': 5, 'col2_1': 5},
+              {'col1': 'c', 'col2': 8, 'col2_1': 4},
+              {'col1': 'd', 'col2': 3, 'col2_1': 3}]
+        self.assertEqual(conn['t1_1'].list(), xs)
+
+        def tempfn2(rs):
+            rs1, rs2 = rs.tee(2)
+            rs1.update(col2=lambda r: r['col2'] + 1)
+            return rs1.order('col2').zip(rs2.new().order('col2 desc')
+                                         .rename(col2_1='col2'))
+
+        conn['t1_1'] = conn['t1'].by('col1').map(tempfn2)
+
+        xs = [{'col1': 'a', 'col2': 5, 'col2_1': 5},
+              {'col1': 'a', 'col2': 6, 'col2_1': 4},
+              {'col1': 'b', 'col2': 2, 'col2_1': 1},
+              {'col1': 'c', 'col2': 4, 'col2_1': 7},
+              {'col1': 'c', 'col2': 5, 'col2_1': 4},
+              {'col1': 'c', 'col2': 8, 'col2_1': 3},
+              {'col1': 'd', 'col2': 3, 'col2_1': 2}]
+        self.assertEqual(conn['t1_1'].list(), xs)
+
     def test_index(self):
         conn = Conn(self.dbfile)
         conn['t1'] = self.t1
@@ -75,10 +148,10 @@ class TestCore(unittest.TestCase):
         def cnt():
             n = 0
 
-            def innerfn(ds):
+            def innerfn(rs):
                 nonlocal n
                 n += 1
-                return ds.update(n=lambda r: n)
+                return rs.update(n=lambda r: n)
             return innerfn
 
         conn['t1_1'] = conn['t1'].by('col1').map(cnt())
@@ -102,9 +175,9 @@ class TestCore(unittest.TestCase):
 
         conn['t1'] = self.t1
         conn['t1_1'] = conn['t1'].by('col1').fold(
-            sum=lambda ds: sum(ds['col2']),
-            mm0=lambda ds: min(ds['col2']),
-            mm1=lambda ds: max(ds['col2'])
+            sum=lambda rs: sum(rs['col2']),
+            mm0=lambda rs: min(rs['col2']),
+            mm1=lambda rs: max(rs['col2'])
         )
 
         self.assertEqual(conn['t1_1'].list(),
@@ -114,9 +187,9 @@ class TestCore(unittest.TestCase):
                           {'col1': 'd', 'sum': 2, 'mm0': 2, 'mm1': 2}])
 
         conn['t1_1'] = conn['t1'].windowed(4, 3).fold(
-            sum=lambda ds: sum(ds['col2']),
-            mm0=lambda ds: min(ds['col2']),
-            mm1=lambda ds: max(ds['col2'])
+            sum=lambda rs: sum(rs['col2']),
+            mm0=lambda rs: min(rs['col2']),
+            mm1=lambda rs: max(rs['col2'])
         )
         self.assertEqual(conn['t1_1'].list(),
                          [{'sum': 13, 'mm0': 1, 'mm1': 5},
@@ -124,9 +197,9 @@ class TestCore(unittest.TestCase):
                           ])
 
         conn['t1_1'] = conn['t1'].windowed(4, 5).fold(
-            sum=lambda ds: sum(ds['col2']),
-            mm0=lambda ds: min(ds['col2']),
-            mm1=lambda ds: max(ds['col2'])
+            sum=lambda rs: sum(rs['col2']),
+            mm0=lambda rs: min(rs['col2']),
+            mm1=lambda rs: max(rs['col2'])
         ).rename(
             mm1='mm0',
             mm0='mm1'
@@ -137,9 +210,9 @@ class TestCore(unittest.TestCase):
                           ])
 
     def test_by(self):
-        def sum_by_col1(ds):
-            tot = sum(ds['col2'])
-            return ds.update(col2=lambda r: tot).islice(1)
+        def sum_by_col1(rs):
+            tot = sum(rs['col2'])
+            return rs.update(col2=lambda r: tot).islice(1)
 
         conn = Conn(self.dbfile)
         conn['t1'] = self.t1
@@ -177,13 +250,13 @@ class TestCore(unittest.TestCase):
         self.assertEqual(conn['t1'].list(), conn['t1_copy'].list())
 
     def test_by_after_map(self):
-        def sumit(ds):
-            tot = sum(ds['col2'])
-            return ds.update(tot=lambda r: tot)
+        def sumit(rs):
+            tot = sum(rs['col2'])
+            return rs.update(tot=lambda r: tot)
 
-        def count(ds):
-            n = len(ds.list())
-            return ds.update(cnt=lambda r: n)
+        def count(rs):
+            n = len(rs.list())
+            return rs.update(cnt=lambda r: n)
 
         conn = Conn(self.dbfile)
         conn['t1'] = self.t1
@@ -204,10 +277,10 @@ class TestCore(unittest.TestCase):
         conn = Conn(self.dbfile)
         conn['t1'] = self.t1
         conn['t1_1'] = conn['t1'].update(col3=lambda r: 1).by('col1', 'col3')\
-            .map(lambda ds: ds)
+            .map(lambda rs: rs)
 
         conn['t1_2'] = conn['t1'].update(
-            col3=lambda r: 1).by('col1').map(lambda ds: ds)
+            col3=lambda r: 1).by('col1').map(lambda rs: rs)
         self.assertEqual(conn['t1_1'].list(), conn['t1_2'].list())
 
         conn['t1_1_double'] = conn['t1_1']\
@@ -265,8 +338,8 @@ class TestCore(unittest.TestCase):
         conn = Conn(self.dbfile)
         conn['t1'] = self.t1
 
-        def add1(ds):
-            return ds.update(col2=lambda r: r['col2'] + 1)
+        def add1(rs):
+            return rs.update(col2=lambda r: r['col2'] + 1)
 
         self.assertEqual(conn['t1'].windowed(4, 2).map(add1).list(),
                          [{'col1': 'a', 'col2': 5},
@@ -425,12 +498,12 @@ class TestCore(unittest.TestCase):
         self.assertEqual(conn['t1_1'].list()[0]['col2'], 5)
 
         conn['t1_col2sum_groupby_col1'] = conn['t1'].by('col1')\
-            .fold(col2_sum=lambda ds: sum(ds['col2']))\
+            .fold(col2_sum=lambda rs: sum(rs['col2']))\
             .deselect('col2')
 
         conn['t1_col2sum_groupby_col1_1'] = conn['t1']\
             .order('col1', 'col2 desc').group('col1')\
-            .fold(col2_sum=lambda ds: sum(ds['col2']))\
+            .fold(col2_sum=lambda rs: sum(rs['col2']))\
             .deselect('col2')
 
         self.assertEqual(conn['t1_col2sum_groupby_col1'].list(),
